#coding:utf-8
import time

from contextlib import contextmanager
from random import random

DEFAULT_EXPIRES = 15
DEFAULT_RETRIES = 5

@contextmanager
def dist_lock(key, client):
    key = 'lock_%s' % key

    try:
        t = _acquire_lock(key, client)
        yield t
    finally:
        _release_lock(key, client)

def ask_lock(key,client):
    key = 'lock_%s' % key
    if client.get(key):
        return True
    else:
        return False
    

def _acquire_lock(key, client):
    while 1:
        get_stored = client.get(key)
        if get_stored:
            time.sleep(0.03)
        else:
            if client.setnx(key, 1):
                client.expire(key,DEFAULT_EXPIRES)
                return True
    return False

def _release_lock(key, client):
    client.delete(key)



#coding:utf-8

import os
from setuptools import setup


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
      name='redis_netlock',
      version = '1.6',
      author="ruifengyun",
      author_email="rfyiamcool@163.com",
      url="http://xiaorui.cc/",
      classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
      ],
      install_requires=['redis'],
      packages=['redis_netlock'],
      platforms=["Any"],
      license = "MIT",
      keywords=['redis lock distributed','fengyun'],
      description="一个用redis做的分布式锁，含有超时及重试机制.",
      long_description=open('README.md').read(),
)
